@@ -116,7 +116,10 @@ class Check:
             comparison_result = comparator.compare(actual)
             if comparison_result.exception is not None:
                 print('ERROR')
+                print('ERROR DETAILS:')
                 comparison_result.print()
+                print('RAW DATA:')
+                print(repr(actual))
                 raise comparison_result.exception
             else:
                 print('OK')
